

SesameQuery
====================================

.. currentmodule:: pyvo.nameresolver.sesame

.. autoclass:: SesameQuery
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SesameQuery.aliases
      ~SesameQuery.baseurl
      ~SesameQuery.database_codes
      ~SesameQuery.dbs
      ~SesameQuery.fluxes
      ~SesameQuery.ignorecache
      ~SesameQuery.names
      ~SesameQuery.opts

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~SesameQuery.execute
      ~SesameQuery.execute_stream
      ~SesameQuery.getqueryurl
      ~SesameQuery.useDatabases
      ~SesameQuery.useDefaultDatabase

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: aliases
   .. autoattribute:: baseurl
   .. autoattribute:: database_codes
   .. autoattribute:: dbs
   .. autoattribute:: fluxes
   .. autoattribute:: ignorecache
   .. autoattribute:: names
   .. autoattribute:: opts

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: execute
   .. automethod:: execute_stream
   .. automethod:: getqueryurl
   .. automethod:: useDatabases
   .. automethod:: useDefaultDatabase

   
   